##  Ignoring IT Component Fact Sheets
You can ignore a fact sheet if you don't want to link it to any catalog item. The fact sheet is moved to the Ignored tab. If needed, you can link ignored fact sheets to catalog items later.
Reasons to ignore include:
  * It is a proprietary product, and you do not expect the catalog to have information about it.
  * You want to overwrite the information in the linked fact sheet. Ignoring a linked fact sheet effectively unlinks the fact sheet and stops updates from the catalog.


If you used a filter in the inventory, you can ignore multiple fact sheets in bulk on the Unlinked tab. To do that, select fact sheets, then click Ignore Selected. When the Filter by confidence filter is applied, the option to bulk ignore fact sheets is not available.
**Note**
Ignoring a linked fact sheet halts updates from the catalog.
